%global blaslib openblas

%define major     3
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           igraph
Version:        0.10.13
Release:        %mkrel 1
Summary:        Library for creating and manipulating graphs
License:        GPLv2+
Group:          System/Libraries
URL:            https://igraph.sourceforge.net/
Source0:        https://github.com/igraph/igraph/releases/download/%{version}/igraph-%{version}.tar.gz
Source1:        https://igraph.org/c/doc/igraph.info

BuildRequires:  pkgconfig(arpack)
BuildRequires:  pkgconfig(gmp)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  %{blaslib}-devel
BuildRequires:  glpk-devel
BuildRequires:  suitesparse-devel
BuildRequires:  cmake

%description
igraph wants to be an efficient platform for
1) complex network analysis and
2) developing and implementing graph algorithms.
It provides flexible and efficient data structures for graphs and related
tasks. It also provides implementation to many classic and new graph
algorithms like: maximum flows, graph isomorphism, scale-free
networks, community structure finding, etc.

#------------------------------------------------

%package -n     %{libname}
Summary:        Library for creating and manipulating graphs
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
igraph wants to be an efficient platform for
1) complex network analysis and
2) developing and implementing graph algorithms.
It provides flexible and efficient data structures for graphs and related
tasks. It also provides implementation to many classic and new graph
algorithms like: maximum flows, graph isomorphism, scale-free
networks, community structure finding, etc.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{develname} package contains the header files and some
documentation needed to develop application with %{name}.

#------------------------------------------------

%prep
%autosetup

%build
%cmake \
    -DIGRAPH_ENABLE_LTO=AUTO \
    -DIGRAPH_ENABLE_TLS=1 \
    -DIGRAPH_USE_INTERNAL_BLAS=0 \
    -DIGRAPH_USE_INTERNAL_LAPACK=0 \
    -DIGRAPH_USE_INTERNAL_ARPACK=0 \
    -DIGRAPH_USE_INTERNAL_GLPK=0 \
    -DIGRAPH_USE_INTERNAL_CXSPARSE=0 \
    -DIGRAPH_USE_INTERNAL_GMP=0 \
    -DBLAS_LIBRARIES=-l%{blaslib} \
    -DLAPACK_LIBRARIES=-l%{blaslib} \
    -DIGRAPH_GRAPHML_SUPPORT=1 \
    -DCMAKE_INSTALL_INCLUDEDIR=include/
%cmake_build

%install
%cmake_install

install -Dm0644 doc/igraph.3 %{buildroot}%{_mandir}/man3/igraph.3
install -Dm0644 %{SOURCE1} %{buildroot}%{_infodir}/igraph.info
find . -name '.arch-ids' | xargs rm -rf

%files -n %{libname}
%license COPYING
%doc AUTHORS NEWS
%{_libdir}/libigraph.so.%{major}{,.*}

%files -n %{develname}
%doc examples
%{_includedir}/igraph/
%{_libdir}/libigraph.so
%{_libdir}/pkgconfig/igraph.pc
%{_mandir}/man3/igraph.3*
%{_infodir}/igraph.info*
%{_libdir}/cmake/igraph/


%changelog
* Sun Sep 15 2024 daviddavid <daviddavid> 0.10.13-1.mga10
+ Revision: 2096751
- new version: 0.10.13

* Tue Apr 23 2024 daviddavid <daviddavid> 0.10.11-1.mga10
+ Revision: 2060647
- new version: 0.10.11

* Thu Feb 15 2024 daviddavid <daviddavid> 0.10.9-1.mga10
+ Revision: 2041321
- new version: 0.10.9

* Mon Oct 30 2023 daviddavid <daviddavid> 0.10.7-1.mga10
+ Revision: 2002910
- new version: 0.10.7

* Sun Jan 08 2023 daviddavid <daviddavid> 0.10.3-1.mga9
+ Revision: 1931586
- new version: 0.10.3

* Thu Dec 29 2022 daviddavid <daviddavid> 0.10.2-1.mga9
+ Revision: 1927818
- new version: 0.10.2
- libify pkg
- lib major is now 3

* Fri Jun 24 2022 papoteur <papoteur> 0.9.6-3.mga9
+ Revision: 1866023
- Mass Rebuild for dependencies

* Sat Apr 02 2022 umeabot <umeabot> 0.9.6-2.mga9
+ Revision: 1840552
- Mageia 9 Mass Rebuild

* Mon Jan 24 2022 mrambo3501 <mrambo3501> 0.9.6-1.mga9
+ Revision: 1769665
- version 0.9.6

* Sat Jul 03 2021 joequant <joequant> 0.9.4-1.mga9
+ Revision: 1734608
- update to 0.9.4

* Fri Oct 09 2020 shlomif <shlomif> 0.8.3-1.mga8
+ Revision: 1632962
- New version 0.8.3

* Wed Aug 19 2020 ovitters <ovitters> 0.8.2-2.mga8
+ Revision: 1616028
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Wed May 06 2020 shlomif <shlomif> 0.8.2-1.mga8
+ Revision: 1580821
- New version 0.8.2

* Fri Mar 20 2020 shlomif <shlomif> 0.8.1-1.mga8
+ Revision: 1558317
- New version 0.8.1

* Thu Feb 20 2020 umeabot <umeabot> 0.8.0-2.mga8
+ Revision: 1547312
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 shlomif <shlomif> 0.8.0-1.mga8
+ Revision: 1487874
- New version 0.8.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Dec 25 2019 shlomif <shlomif> 0.7.1-3.mga8
+ Revision: 1469962
- Patch from fedora: MGA#258937 / CVE-2018-20349

* Sun Sep 23 2018 umeabot <umeabot> 0.7.1-2.mga7
+ Revision: 1298284
- Mageia 7 Mass Rebuild

* Sun Dec 03 2017 shlomif <shlomif> 0.7.1-1.mga7
+ Revision: 1181099
- fix rel
- Fixes for build.
- import from MGA#21312 - thanks

